Sample statistics and hypothesis tests
======================================

.. toctree::
    :maxdepth: 1

    analysing_one_sample
    comparing_two_samples
    resampling

Statistical hypothesis tests are used to decide whether data sufficiently
support a particular hypothesis. SciPy defines a number of hypothesis tests,
listed in :ref:`hypotests`. You can find examples to each test in the
corresponding docstring.
